@@ -15,6 +15,6 @@ impl OpenOptionsMaybeDirExt for cap_primitives::fs::OpenOptions {
         // `maybe_dir` functionality is implemented within `cap_primitives`;
         // we're just exposing it here since `OpenOptions` is re-exported by
         // `cap_std` etc. and `maybe_dir` isn't in `std`.
-        unsafe { self._cap_fs_ext_maybe_dir(maybe_dir) }
+        self._cap_fs_ext_maybe_dir(maybe_dir)
     }
 }
